package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````E1<``#0```"D@0````0`!30`(``)
M`"@`'``;``$``'#,?```S'P``,Q\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#8?```V'P```4`````$```
M`0```+Q]``"\C0``O(T``(P"``"@`@``!@`````0```"````Q'T``,2-``#$
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!```P`0``,`$```0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO'T`
M`+R-``"\C0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`RI]-^DA<!O$U\62>IX&ZPO,.[9L$
M````;````'X:_LI&1$\`>R)T>7!E(CHB9&5B(BPB;W,B.B)U8G5N='4B+")N
M86UE(CHB;&EB<&%R+7!A8VME<BUP97)L(BPB=F5R<VEO;B(Z(C$N,#8S+3%B
M=6EL9#$B+")A<F-H:71E8W1U<F4B.B)A<FUH9B)]````!````&````!^&O[*
M1D1/`'LB='EP92(Z(F1E8B(L(F]S(CHB=6)U;G1U(BPB;F%M92(Z(F=L:6)C
M(BPB=F5R<VEO;B(Z(C(N-#`M,75B=6YT=3,B+")A<F-H:71E8W1U<F4B.B)A
M<FUH9B)]``````0````0`````0```$=.50```````P````(`````````$0``
M`$L````(````"`````&0$`0E0`2`*(``!:"&4(2`@0`""R@$C#B`$D&*```(
M2P```$P```!/````4P```%0```!=````7@```%\`````````80```&(```!C
M````9````&4```!H```````````````!KS3H;L7?'\[>1RUK?YI\+L6;MM1D
MU'QV5#R4(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_+%COEWFZXY)\^J%L
M8)E/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0
MO]I7&Z/@^TD``````````````````````````,02`````````P`,````````
MD`````````,`%P`)`@`````````````2````Y```````````````$@```/H"
M`````````````!(```#%`@`````````````2````MP(`````````````$@``
M`)8``````````````!(```!=`0`````````````2````^@``````````````
M$@````$``````````````"````"P`@`````````````2````)0(`````````
M````$@```"L!`````````````!(````;`0`````````````2````O@(`````
M````````$@````T!`````````````!(```#4`0`````````````2````$```
M````````````(````'L!`````````````!(```#-`@`````````````2````
MZ0``````````````$@```/<!`````````````!(```#4`@`````````````2
M````+```````````````(````/P!`````````````!(```!&````````````
M```2````8P``````````````%@```$T!`````````````!(```!V````````
M```````2````TP``````````````$@```(<``````````````!(```#J`0``
M```````````2````W`$`````````````$@```-L"`````````````!(```#D
M`P`````````````2````MP``````````````$@````H#`````````````!$`
M``#-`0`````````````2````)`,`````````````$0````\"````````````
M`!(````_`0`````````````2````Q`$`````````````$@```(,"````````
M`````!(```"]`0`````````````2````[@``````````````$@```*L!````
M`````````!(```!T`0`````````````2````E0$`````````````$@```&,"
M`````````````!(```#C`0`````````````2````\0$`````````````$@``
M`!(#`````````````!(```"B```````````````2````'@(`````````````
M$@```&@!`````````````!(````V`@`````````````2````"`,`````````
M````$0```),"`````````````!$```#&```````````````1````LP$`````
M````````$@```(8!`````````````!$```!'`@`````````````2``````,`
M````````````$@```#0!`````````````!(```!5`@`````````````2````
M/P(`````````````$@```%0``````````````!(```!Q`@`````````````2
M````F@(`````````````$@```.("`````````````!(```"F`0``````````
M```2````Z0(`````````````$@```*$"`````````````"(````_!```7)``
M```````0`!@`[0,``,DM``#`````$@`.`&0$``#])@``^`0``!(`#@!^`@``
MR14``,P!```2``X`9`,```D>```$````$@`.`((#``#U*P``U`$``!(`#@`5
M!```2)`````````0`!@`B@0```T>``"@`0``$@`.`$H$``!(D````````!``
M&`!U`P``K1\``!@````2``X`F`,``&TD``!@````$@`.`/D#``#4.@``!```
M`!$`$``C!```(3D``-X````2``X`+@0``"$=```\````$@`.`#8$``!<D```
M`````!``&`!?!```7)`````````0`!@`>`0``$$F``"\````$@`.`*$$``#-
M)```2````!(`#@`(!````)`````````0`!<`O`,``,4?```,`0``$@`.`'$$
M``!(D````````!``%P"7!```1)````0````1`!<`#@0``)47````````$@`.
M`%8$``"M.```=````!(`#@`*!````)`````````@`!<`T@,``#$F```0````
M$@`.`*8#``!='0``K````!(`#@#(`P```3H``+P````2``X`/@0``%R0````
M````$``8`*D$``#1(```G`,``!(`#@``7U]G;6]N7W-T87)T7U\`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O
M;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E
M=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!03%]M96UO<GE?=W)A<`!?7W-T86-K7V-H:U]F86EL`&5X:70`
M;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R
M8VAR`'5N;&EN:P!S=')T;VL`<W1R;&5N`')M9&ER`')E860`7U]M96UC<'E?
M8VAK`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T-C1?=&EM
M938T`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7VUE;6UO=F5?
M8VAK`%]?9G!R:6YT9E]C:&L`7U]L:6)C7W-T87)T7VUA:6X`7U]S=&%T-C1?
M=&EM938T`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE
M;6-M<`!M96US970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C
M;7``7U]E<G)N;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?
M7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O
M+C4N-#``;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`<&%R7V-U<G)E
M;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A
M<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE
M`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE
M86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?
M7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S
M<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE
M`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS-````````````@`!
M``(``@`"``$``0`!``$``@`#``$``0`"``$``@`!``$``@`"``(``@`!``(`
M`0`!``$``0`!``$``@`"``(``@`!``(``@`$``(``0`"``,``@`!``(``@`"
M``(``@`"``(``0`"``$``@`"``(``0`"``$``@`"``$``@`"``$``P`"``(`
M`@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$````!``$`4`,``!`````@````%&EI#0``
M!`"V!`````````$``@!&`P``$`````````"TD98&```#`,`$```0````%&EI
M#0```@"V!````````+R-```7````P(T``!<```#\CP``%P````20```7````
M%)```!<````8D```%P```""0```7````))```!<````HD```%P```"R0```7
M````,)```!<````XD```%P```#R0```7````1)```!<```#(CP``%0H``,R/
M```5"P``T(\``!43``#4CP``%1D``-B/```3'```W(\``!4=``#@CP``%1X`
M`.2/```5)@``Z(\``!4H``#LCP``%3L``/"/```5/```](\``!4^``#XCP``
M%4H``-B.```6`P``W(X``!8$``#@C@``%@4``.2.```6!@``Z(X``!8'``#L
MC@``%@@``/".```6"0``](X``!8+``#XC@``%@P``/R.```6#0```(\``!8.
M```$CP``%@\```B/```6$```#(\``!81```0CP``%A(``!2/```6%```&(\`
M`!85```<CP``%A8``""/```6%P``)(\``!88```HCP``%AH``"R/```6&P``
M,(\``!8?```TCP``%B```#B/```6(0``/(\``!8B``!`CP``%B,``$2/```6
M)```2(\``!8E``!,CP``%B<``%"/```6*0``5(\``!8J``!8CP``%BL``%R/
M```6+```8(\``!8M``!DCP``%BX``&B/```6+P``;(\``!8P``!PCP``%C$`
M`'2/```6,@``>(\``!8S``!\CP``%C0``("/```6-0``A(\``!8V``"(CP``
M%C<``(R/```6.```D(\``!8Y``"4CP``%CT``)B/```6/P``G(\``!9```"@
MCP``%D$``*2/```60@``J(\``!9#``"LCP``%D0``+"/```610``M(\``!9&
M``"XCP``%D<``+R/```62```P(\``!9)``#$CP``%DH```A`+>D^`0#K"("]
MZ`3@+>4$X)_E#N"/X`CPON7L>P```,:/X@?*C.+L^[SE`,:/X@?*C.+D^[SE
M`,:/X@?*C.+<^[SE`,:/X@?*C.+4^[SE`,:/X@?*C.+,^[SE`,:/X@?*C.+$
M^[SE`,:/X@?*C.*\^[SE`,:/X@?*C.*T^[SE`,:/X@?*C.*L^[SE`,:/X@?*
MC.*D^[SE`,:/X@?*C.*<^[SE`,:/X@?*C.*4^[SE`,:/X@?*C.*,^[SE`,:/
MX@?*C.*$^[SE`,:/X@?*C.)\^[SE`,:/X@?*C.)T^[SE`,:/X@?*C.)L^[SE
M>$?]YP#&C^('RHSB8/N\Y0#&C^('RHSB6/N\Y0#&C^('RHSB4/N\Y0#&C^('
MRHSB2/N\Y0#&C^('RHSB0/N\Y0#&C^('RHSB./N\Y0#&C^('RHSB,/N\Y0#&
MC^('RHSB*/N\Y0#&C^('RHSB(/N\Y0#&C^('RHSB&/N\Y0#&C^('RHSB$/N\
MY0#&C^('RHSB"/N\Y0#&C^('RHSB`/N\Y0#&C^('RHSB^/J\Y0#&C^('RHSB
M\/J\Y0#&C^('RHSBZ/J\Y0#&C^('RHSBX/J\Y7A'_><`QH_B!\J,XM3ZO.4`
MQH_B!\J,XLSZO.4`QH_B!\J,XL3ZO.4`QH_B!\J,XKSZO.4`QH_B!\J,XK3Z
MO.4`QH_B!\J,XJSZO.4`QH_B!\J,XJ3ZO.4`QH_B!\J,XISZO.5X1_WG`,:/
MX@?*C.*0^KSE`,:/X@?*C.*(^KSE`,:/X@?*C.*`^KSE`,:/X@?*C.)X^KSE
M`,:/X@?*C.)P^KSE`,:/X@?*C.)H^KSE`,:/X@?*C.)@^KSE`,:/X@?*C.)8
M^KSE>$?]YP#&C^('RHSB3/J\Y0#&C^('RHSB1/J\Y0#&C^('RHSB//J\Y0#&
MC^('RHSB-/J\Y0#&C^('RHSB+/J\Y0#&C^('RHSB)/J\Y0#&C^('RHSB'/J\
MY0#&C^('RHSB%/J\Y0#&C^('RHSB#/J\Y0#&C^('RHSB!/J\Y0````!PM5Y-
MBK!>2WU$7DS-Z080!JD%D@>H!:I\1.M8&V@)DT_P``/_]\#O5TI82Z)8`Y(1
M1N-8!),81@+P7/I42^-8'7@`+6/0'>YP+TI+!YA[1!MHQ1P$,+#Q@$_26)+X
MUC-#\`,#@OC6,W32@`#_]VKO2$E)2@-&>40&G'I$"6A08"!HF6!%20>:>439
M8$1)`2H88'E$66!EW2$=!.N"#@/Q#`Q1^`1+3/@$3XY%^='1'#Q,`"!#^"$`
M*D9\1#I)`)!Y1.!H__=.[@`H,=`W30BN?43H:/_WWNX$1C5(,49X1`#P\OA`
MLS-+>T38:/_W'.[_]Y3N,$HB2WI$TU@::`F;6D!/\``#,M$@1@JP<+W_]V#N
M*DIZ1-!@,+/_]XSN%DL=[G`O>T0;:--8@_B&5HSGX&C_]S#NR>>H:!"Q`?!@
M^]'G'T@Q1GA$`/"^^*A@`"C)T//G&TL<2'A$XU@#DQE&__?D[@0AH^<!(/_W
M-N__][[N`+^^>0``Z'@``/AX```<`0``Z'@``/P````4`0``)`$```)Z```&
M>@``."@``"HH``#&>0``*08``+!Y``"")0``F'D```AX``!L>0``MB0``"@!
M``"D)@``3_``"T_P``X"O&I&!+0!M-_X&*`%HYI$3_```PBT!$A:^```__?@
M[O_WGNT,=P``,`$``!0PG^44()_E`S"/X`(@D^<``%+C'O\O`=3^_^KT=@``
M``$```9(!TL'2GA$>T1Z1(-"`]`%2]-8`[$81W!'`+]2>```4'@``-)V```$
M`0``"$@)2WA$"4I[1!L:>D39#P'KHP%)$`/0!4O36`.Q&$=P1P"_*'@``"1X
M``"D=@``"`$```BU"DL*2GM$>D0;>&NY"4O36".Q"$M[1!AH__>H[O_WO_\&
M2P$B>T0:<`B]\G<``'1V```L`0``GG<``-)W``#$YP"_+>GX0QU+'DI[1)M8
MT_@`D+GQ``\PT`5X@$8/1@`M&+\]+12_`24`)1/1V?@`0&RQ3D8J1D%&($;_
M]SCN$+EC73TK$-!6^`1/`"SRT2!&O>CX@P5&%?@!/P`K&+\]*_G1I>L(!>'G
MINL)!@$U+$2V$#Y@($:]Z/B#3$;GYS!V```8`0``%TH82WI$$+4$1IZPTUAI
M1AMH'9-/\``#__<0[:"Y!)L#]'!#L_4@3QB_L_6`3PW0#4H,2WI$TU@::!V;
M6D!/\``#"]$>L!"]`"#QYP(A($;_]S+ML/J`\$`)Z>?_]Z#ML'4``!P!``"`
M=0``-DHW2WI$\+6AL--8&V@?DT_P``,0L0-X!$9;N3%*,$MZ1--8&F@?FUI`
M3_```U/1(;#PO?_WJ.P%1@`H[M`H1O_WL.T`*#;0PWP`\1,&+BL"T7-X`"OR
MT,-\+BLRT"!&__<2[0=&,$;_]P[M!T0"-SA&__=:[1Q+.D8"(7M$`98`E`9&
M__>4[0*I,$;_]S+M`3`P1@70!IL#]'!#L_6`3Q?0__?X[#!&__?$["A&__=Z
M[0`HR-$H1O_W%NT@1O_W3.VKYW-X+BO)T;-X`"NVT,7G__>5_^;G__<L[41U
M```<`0``*'4``&@A``!:2EM+>D0MZ?!/#$:#L`5&TUC?^&"!&V@!DT_P``,+
M>/A$/2L(OP$T($;_][CL:48&1BA&__?V_H%&`"A4T/_WKNR&0D?93$L`GUCX
M`X"_`"MX`"L8OSTK%+\!(P`C!]`K1A/X`2\`*AB_/2KYT5L;L!S8^`!@&$3_
M]^#L\%'HL=CX`#`H1ME9$/@!.PMP/2L8OP`K"=!*'!#X`3L11@+X`3L`*QB_
M/2OVT0I&/2,+<!3X`3L"^`$_`"OYT2]*+$MZ1--8&F@!FUI`3_```TK1`["]
MZ/"/"?'_.13X`3L)^`$_`"OYT>GG(TM8^`.`V/@`<#MHF[,[1E/X!"])1@GQ
M`0D`*OC1`S%/ZH$+'$M[1!IHPKE81@$B&F#_]Y#L@D8`*,O0.49/ZHD'6T8Z
M1O_WWNS(^`"@S?@`D`GQ`0D`(TKX*3"$YUE&.$;_]];L@D;(^````"BQT$_J
MB0?KYYE&3_`("]+G__=P[`"_6'0``!P!```\=```&`$``)QS``#.=```+>GP
M00]&*TDK2ZWU@%UY1(*P!D8-]8!0!#`-\00(RUA`]O]R048;:`-@3_```R-(
M>$3_]WKL!!X&W6,>#>L##)SX!"#JN=NY&$L=[G`/.D8Q1GM$&VC`6/_WFNL8
M2@WU@%$52P0Q>D336!IH"VA:0$_P``,8T0WU@%T"L+WH\($<1B)&+R%`1O_W
MANP`*-O0!T@=[G!?(T9"1GA$`&@Q1BA8__?2Z]GG__<,[))S``!*<P``RG(`
M`!P!``!,'P``<G(``#"U'>YP3Q)*#TF%L!%(>D1Y1`EH$$L`)7M$$EA@6`])
M`Y)Y1/_W..P(20U+>40):`Q*>T1Z1&!8"TD!E7E$`)/_]WSK!;`PO1!S``#T
M<@``!G(``!`!``!87P``IAX``)HA```)#P``J!X```I*@K`*21WN<,]Z1`9(
M"4MX1`!H4EA[1`=)7/@``'E$`9("L/_W`+RD<@``GG$``!`!``#N7@``/AX`
M`"5*\+4E2WI$K?4`78>P#?4`40.LTU@4,0WU@%8;:`M@3_```__WONL=2@(A
M'4L0-GI$S>D``GM$($9!\@$"__?*ZR!&3_2`4C%&__>XZP0>N+\`)0S;9QPX
M1O_W>.L%1C"Q.T8Q1B)&__<(ZP`C*U4-2@WU`%$)2Q0Q>D336!IH"VA:0$_P
M``,$T2A&#?4`70>P\+W_]V#K9G$``!P!```P'@``'AX``/)P``#_]ZB_6THM
MZ?!/!D9:2WI$K?6$78.P64@-]815#?$0"--8#$9X1$%&!#4;:"M@3_```__W
M*?TO(05&,$;_]W[JP+%/2#%&>$3_]PS^,$9-2@WUA%%(2P0Q>D336!IH"VA:
M0$_P``-`\(.`#?6$70.PO>CPCR!&__<"ZT-)>43_]R+K!$8`*-S0(W@-\8@*
MW_C\D*KQ!`?Y1``K2-`EL2%&*$;_]W3KN+,@1O_WJNI#'B-$@T:<0CZ_(Q@`
M(6`<`],*X)A"&7`#T!/X`2TO*OC0($;_]Y;J@T8P1O_WDNI81`$PL/6`7ZS2
M*4@"(4M&3_2`4GA$`)3-Z0$&.$;_]Q3K048X1O_WLNHPN5KX:#P#]'!#L_4`
M3Q?0'DD`('E$__?2Z@1&`"B,T"-X`"NVT=6Q*W@N*P30&$Q/\`$+?$3+YVMX
M`"OHT/;G`2$X1O_W.NH`*.'1$4@Y1GA$__>#_3A&__>,ZG/G#DQ/\`$+?$2S
MY__WG.JR<```'`$``)@=``""'0``:'```%P=``!&'0``\AP``+P<``!\'```
M<!P``$P<```0M2\A!$;_]^SI`+%$'"!&O>@00/_W7KH[2O"U.TMZ1*WU@%V#
ML`WU@%'36`0Q&V@+8$_P``,`*#S0`W@%1@`K.-#_]PSJ0AP$1K+U@%]'V`&O
M*48X1O_W#NIC'CM$GT(+TC@9#?$%`@`A`N"00@%P`]`0^`$]+ROXT"\A.$;_
M][#I>+.X0H2_`",#<#A&__<DZA]*#?6`41Q+!#%Z1--8&F@+:%I`3_```RO1
M#?6`70.P\+T72@WU@%$42P0Q>D336!IH"VA:0$_P``,:T1)(>$0-]8!=`["]
MZ/!`__?ZN0`@UN<-2@WU@%$(2P0Q>D336!IH"VA:0$_P``,"T0A(>$3FY__W
M`.K^;@``'`$``(!N``!>;@``1!L``"YN```4&P``S$K-2WI$<+7,3H*PS$W3
M6'Y$;$9]1!MH`9-/\``#(48P1O_WS?NPL<9+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__>W^P`HZ-&\3GY$(48P1O_WK_NPL;=+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>9^P`HZ-&N3GY$
M(48P1O_WD?NPL:A+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__=[^P`HZ-&@3GY$(48P1O_W<_NPL9E+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__==^P`HZ-&23GY$(48P1O_W5?NPL8I+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<_^P`HZ-&$3GY$
M(48P1O_W-_NPL7M+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__<A^P`HZ-%V3GY$(48P1O_W&?NPL6Q+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__<#^P`HZ-%H3GY$(48P1O_W^_JPL5U+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?E^@`HZ-%:3GY$
M(48P1O_WW?JPL4Y+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__?'^@`HZ-%,3GY$(48P1O_WO_JPL3]+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__>I^@`HZ-$^3GY$(48P1O_WH?JPL3!+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>+^@`HZ-$P2"%&
M>$3_]X3Z`488L2U(>$3_]VS[+$@A1GA$__=Y^@%&&+$J2'A$__=A^RE((49X
M1/_W;OH!1K"Q)DAX1/_W5OLE2A%+>D336!IH`9M:0$_P``,5T2%)(DAY1'A$
M`K"]Z'!`__=#NQ]((49X1/_W4/H!1@`HY-`<2'A$__<W^]_G__=8Z/1M```<
M`0``$!L``.1M```8`0``U!H``*`:``!P&@``/!H``!`:``!P&0``I!D``'09
M``!$&0``C!@``-88``"R&```U!@``-P8``#>&```"A@```1K``#8&```/A@`
M`+(8```\&```$TH42WI$`+432(.PTUAX1&E&&V@!DT_P``/_]P/Z0+$`>``H
M&+\P*`R_`2``((#P`0`*2@=+>D336!IH`9M:0$_P``,"T0.P7?@$^_[W_.]8
M:@``'`$``+H7```F:@``#[3?^#3``+4,2OQ$@[`$JPM)#$A<^`(@>402:`&2
M3_```E/X!"L`DPA8`B$`:/[WJN__(/_W3NCR:0``'`$``.1I```@`0``+>GP
M1P(A/TRM]8`]`"*&L'Q$#?6`-0`C%#6`1@"1.DEA6`EH*6!/\``!_O>N[P$X
M8?$`!_H7@.H"`YL:F[)30)L:8NL"`L8:9^L"!P`O2]M/\`@)P/(!"0.M`"$R
M1CM&0$8`D?[WD.^Q\?\_"+^P\?\_0=!*1BE&0$;^]QCO0QPVT`<H)MD(."P8
M(]+?^'R@^D0"X`$\K$(<TP@B448@1O[WKNX`*/719!N@&4?KY'$72@WU@#04
M2Q0T>D336!IH(VA:0$_P``,:T0WU@#T&L+WH\(>V]8`V9_$`![?Q_S\(OQ;U
M@#^XT4_P_S`!1M_G"$AX1/_W8/\'2'A$__=<__[W3N^D:0``'`$``&!J``#Z
M:```OA8``*86```(M?[WN.[^]_KN`+$`:`B])DHG2WI$\+4F3X>P!4;36']$
M!*DX1AMH!9-/\``#__<7^1"Q`W@$1HNY'TH<2WI$TU@::`6;6D!/\``#+-$;
M2"E&>$0'L+WH\$#_]^^Y*$;^][KN!D8@1O[WMNX&1`(V,$;^]P+O$DL223)&
M>T0"E'E$`)4!D0(A!$;^]SKO#DH'2WI$TU@::`6;6D!/\``#!+\A1CA&U=#^
M]^SNA&@``!P!``"`%@``6F@``$X6```X%0``,!4```9H```MZ?!/W_AL),&P
MW_AL%'I$W_AH5'E$)J\(DGU$W_A@)`7Q#`,'D`7Q&`PLK#`U)D8-\:0)BE@-
M\2@($F@_DD_P``*3Z`<`A^@'`+SH#P`/QISH`P"&Z`,`E>@'`(GH!P#?^"`$
M049X1/_WE/@@L0-X!48`*T#P?H'^]Q;N_O=8[@`H`/"O@`9H`"X`\*N`,$;^
M]SSN0@`"\0$*4$;^]X;N!48P>``H`/!W@=-&"97?^-B3^4121DM&`)`"(2A&
M`C7^][CNTT46^`$/6T8XOU-&H^L*`JKQ`@H",JKK`PJ:0BR_DD2:1``HY-'H
M2'A$`N!4^`0/B+%!1O_W3/@%1@`H]M`#>``K\]#_]X;X`"COT"A&_O<Z[@1&
MB+E7^`1+=+$C>``K`/`0@2!&__=U^``H\]`@1O[W*.X$1@`H[=`@1O[WY.T)
MG09&*$;^]^#M!D0&\@1&,$;^]RKNS4L'1C)&>T0"D\M+`B$#E7M$`9/*2P"4
M>T3^]U[N3_3@<3A&_O<T[0$P!='^]Y3N`6@1*4#PXX!!1CA&_O=>[01&`"@\
MT+Y)")@'F[Y*0%@"(1MH>D0`EP!H_O<&[@`ENDJP2WI$TU@::#^;6D!/\``#
M0/!,@2A&0;"]Z/"/_O?6[09&`"A`\+2`6?@$"UBQ04;^]]+_`"CWT`-X`"ON
MT5GX!`L`*//1J4X-($_P#0O^]]#M?D0%1@F0VD93($GG#IL#]'!#L_6`3[S1
M$)W^]S[MA4*WT0Z;P_,(`[/UX'^QT3!&_O>V[05&F4A!1GA$_O>C_P%&`"@`
M\*.`!YL8:/_W6?J#1@`H`/";@%A&_O=0[8%&`R@0V8])!#A81'E$_O<.[DBY
MN?$$#P#PV8#91!GX!3PO*P#PTX"'2$%&>$3^]WO_(+$#>#`K&+\`*P;16$8`
M(?[W3.V`1@`H==%_28!(>43?^`"B>$3?^/R1__=2^-_X^('^]YCM?4M^2@(A
M>T3-Z0!S?$MZ1`*0*$8#DGM$,D;Z1/E$^$3^]Y[M$^#^]]KM`V@1*Q71_O=^
M[0$TA$931C)&`B$H1LWI`TG-Z0&,`)?^]XKM3_3@<2A&_O=>[`$PY-`X1O[W
MPNQH2"E&>$3_]QCX*$;_]__]..<<1OCF_O?>[$(``O$!"J#F4$H(F`>;@%@;
M:%Y*S>D`<0(A>D0`:/[W*NTAY__WYOU92D%+>D336!IH/YM:0$_P``-MT2A&
M0;"]Z/!/_O?VO`F5IN8'F]/X`+!@Y__W./V!1K'Q``J#V[#Q"@)/\``+:O$`
M`T!&S?@`L/[W[NPRJ08B0$8'D?[W>NP'F08H2=$RFD_TAD/$\D$SFD)_]&BO
MBHA$\DA3FD)_]&*ON?$R`D!&:O$``S2LS?@`L/[WS.Q`1B@B(4;^]UKL*"@J
MT3-+,D8S22A&>T3-Z0!S,4MY1`*4`Y%[1`(AC?CXL/[W_NQZYP>;T_@$D+GQ
M``\_]":O2$;^]V#L`RA_]B"O)DD$.$A$>43^]QSM`"@(O\M&%>?^]Z;L(4AX
M1/_WKOR^9P``N&<``.YH```<`0``8A0``#H5``"8%```H!0``(83``""%```
M(`$``)84```.9@``UA,``%`4```H%```H!(``/@2``!V$@``[A,``)04``#^
M$0``%A(``*(4``#B$P``CA$``)X2``!09```TA```%X3``"0$@``3A(``$(2
M``!D265*>41PM5I+@K`=[G!/BEAI1F%(;D82:`&23_```GM$&VAX1.58E?AH
M,(7X:3#^]S3^$+$#>#$K?-#_]T[Z34M[1!MHY5A522A&`R,!(GE$_O>0ZP5&
M<+$":4=+>T0;:!%H3TK@6'I$_O>0ZRMI&6B+:%L":M1!20,C`2)Y1`EH8%A(
M27E$_O=TZP5&>+%&2#%&>$3^]P'^*VD"1AEH`"A,T#=+>T0;:.!8_O=NZS5+
M`2(^27M$&VAY1.58*$;^]S3K.TH!1BA&>D0Z3?[W7NLN2SE(?41[1!MH`")X
M1#%&XUB#^&D@_O?8_01&J&"PL4_TX'$@1O[W^NI"'`-&$2@8OP$J*]@M2B-+
M>D336!IH`9M:0$_P``,?T0*P<+UH:/_W\?P$1JA@`"CAT25(>$3^]^;K0W@`
M*X70?N<B2PA&>T1;:!EH_O=8_[#G$$M[1!MHX%C^]Z+KC>?^][#K&DDB1AI(
M>41X1$EH"6C^]\CK`+_`8P``GF,``()C``!B8P``.F,``"IC```(8P``D&(`
M`-!B```<`0```!```*@1``"4$0``?A$``$@/``!.$0``5A$``'YC``#R#@``
MR&$``/@0```28P``[F(``.00```I2BI+>D0PM01&*4B#L--8:49X1!MH`9-/
M\``#_O=4_7"Q`W@P*QB_`"L,OP$C`".#\`$#`"P,OP`C`_`!`UNY'$H:2WI$
MTU@::`&;6D!/\``#)]$#L#"](W@`*_#0($;_]\SX+R$%1O[WK.H`L44<*$;^
M]R3K$$D$(GE$_O=ZZP`HW=$-2@E+>D336!IH`9M:0$_P``,%T2!&`["]Z#!`
M_O>*O?[W(NO\8```'`$``%H.``"\8```N@X``'A@```MZ?!/`T;?^!!*K?4K
M?0/Q@`??^`@Z?$0(J0`F`I`*1D`PO$;C6!MHJ9-/\``#4.D"=%9@UF`0,C^Z
M0O@0?",*)0(#]']#"#!#ZA1C!?1_!4/J!&.$14/J!0-"^`@\YM'=Z2*""JPF
MFPWQB`L`DR2H)JT!]0)S`Y`@1@25S>D%00UHS?@<L)-&W?B4X-WXG,`)G]WX
M+*`DGMWX*)``F0&3`>"11II&`)$`(]#I#A10^`@O0V=10('J"`&P1D-H:4``
MGDU&7$"$Z@L$\T9\0.9&3^K1?$D83.I$#`&<0>H,`5=&3_``#*!"`6?:T0.;
M`IC=^!RP'6@$F]WI!4';^`!@&VC0Z0%[`Y/0Z0,ZT/@`P$_JFPX*:"%H3NJ#
M?H1I1_:9$\7V@B,`E`1JTAA/ZMQ@`91`ZD<0$AD`G$#J3!""&$[JBWZ*Z@0`
M3^J<"0#J"P!)ZH=Y8$!)ZHQY$AB*Z@X`R1@`Z@P`"1G=^#"`@.H*``Z?"!B.
MZ@D!&.L#"!%``.OR8!CK"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!GB>H"`=WX
M0.`!0$_JL`"!Z@D!&.L!`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/ZK<'44`9
MZP$!&.L#"!CK`@F`Z@<"W?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK`P@8ZP`)
M`NOQ8(?J#@+=^%B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX8(`"
M0$_JL`""Z@X"&>L"`ACK`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'2D`9ZP("
M&.L#"!CK`0D"Z_YA@.H'`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8ZP`)`NOQ
M8(?J#@+=^'B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX@(`"0$_J
ML`""Z@X"&>L"`ACK`P@8ZPX.`NOW:('J``(Z0$_JMP=*0![K`@+V&'88@.H'
M`0'J"`$"Z_AB04!/ZK@(<1CM&"T8`>OR8(?J"`$10$_JL@)Y0(CJ`@9I&`.=
M!D`!Z_!A[!@HG4_JL`"&Z@@&Y!F"Z@`'I!GM&!7K"`8/0"J=!.OQ9%=`3^JQ
M`?89@.H!#NT8#NH$#J\8+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8+1@W0"Z8
M3T`$Z_9D[QE/ZK8&PQA;&(+J!@$A0#"=44`'Z_1N6!A.]J$SQO;98T_JM`05
MZP,(,ID8ZP((ANH$`@#K_F""Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK\&&.Z@`.
MDAE/ZK``$NL.`C:>_QB%Z@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V&(#J`0X$
MZ_)DCNH"#G493^JR`A7K#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'3^JT!!;K
M`PX\G1[K`0X'Z_!A@NH$!SZ>1T!/ZK``'NL'#N\8OQ@.Z_%BA.H`#D"=CNH!
M#D_JL0$7ZPX'%NL##A[K!`X'Z_)D@.H!!T*>5T!/ZK("'NL'#N\8/Q@.Z_1@
M@>H"#D2=CNH$#D_JM`07ZPX'@NH$#O88!^OP9X[J``YV&$_JL``6ZPX&1IF$
MZ@`.[1@&Z_=FCNH'#JT83^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.#!E/ZK8&
M%.L.!$J9TAB'Z@8.!.OU9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`Z_1@CNH$
M#LD93^JT!!'K#@%.GX7J!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">_QB$Z@`.
M`NOQ8H[J`0Y]&4_JL0$5ZPX%4I_V&(#J`0XT&8[J`@X%Z_)F%.L.!$_JL@(7
MZP,.5)T>ZP`.@>H"`'!`!.OV9![K``Y/ZK8`[1B"Z@`&:1A6G69`#NOT;HD9
M3^JT!.L86)V;&(#J!`*"Z@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$Z@<.6IXH
M&`[J`0X$Z@<%3NH%#@+K\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F%$`'Z@$.
M3^JR`D3J#@0!Z@(()!CM&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV!A#K#@[@
M&`[K]61`&$+J!@$"Z@8.*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!!NH%#KH8
M(4!BGT_JM`1!Z@X!!>H$"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(`D_JL``2
MZPX"_Q@$Z@`.?1D"Z_%G1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8$AE`Z@$$
M3^JW!@7K]V4\0`#J`0<\0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU8D?J#@=/
MZK4%/!E&Z@4'P!@$Z_)D!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`TA@@0)(9
M!^OT9@7J`0=/ZK0$.$-!Z@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'Z@X'3^JV
M!G\9TAA5&`?K\&%$Z@8'!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J``0&Z@`'
M#$`\0P7K\66D&'2:3^JQ`03K]632&$#J`0<`Z@$.EADO0'::1^H.!T_JM06_
M&=(8%A@'Z_1@0>H%!P'J!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`4A@'Z_!A
M!>H$!T_JL``^0P*?MA@`(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z843J``=\
MF@]`1^H.!T_JL0%_&=(80.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&-4,!Z@0&
M%>L.!=,8&QA!Z@0`.$"`FC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"FG88A.H'
M`6E``.OU8'883^JU!=(8A^H%`109A)I!0`;K\&9D&$_JL`#2&(7J``'7&8::
M!.OV9'%`?QA/ZK8&T1B(FDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*FH;J!``!
MZ_5A:$!/ZK4%/QC0&(`9C)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:A>H!!`#K
M]F!T0#\93^JV!-88D)IV&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&Z_5AA.H`
M!FY`3^JU!;\9UA@V&92:!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K]&"%Z@$&
M9D!/ZK0$OQG6&'89F)H'Z_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU883J``9N
M0$_JM06_&=88-AF<F@?K\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@A>H!!F9`
M3^JT!+\9UAAV&:":!^OP98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$Z@`&;D!/
MZK4%OQG2&!89!^OQ9(#J!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KKMP(R8:::
MA>H!!F9`3^JT!(`9TQB!Z@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#Z_!C`)@[
M8`&;)!BZ8``B>F+)&`M*"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/
M_?<,[@"_*F```!P!``!*5@``"+6`(/WW^NV?[0Y[`"*"9X#M`'N?[0U[@.T"
M>Y_M#7N`[01[G^T->X#M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]`+\!(T5G
M`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,````````````````M
MZ?!'!4861H!J`",/1O07U>D,(0#KQ@R$1>AJ<^L```+2`3)!\0`!J&\%\3@*
MQ>D*PW,/0^K$`YL8*V-!ZU1Q:6.HNS\N*]VF\4`(M@D&\?\Y/$8'ZX86(T92
M1@3Q0`'3^`#`$#-3^`Q,$#)3^`@,4_@$[(M"0O@$[$+X$,Q"^`Q,0O@(#.O1
M'$8H1O_W;/JT0N'10#>HZXD6*/`_"$=$,D8Y1E!&_?<L[:YGO>CPA\#Q0`0%
M\3@*M$)01*B_-$8Y1B)&_?<<[:MO(T2K9T`K[-$H1C8;)T3_]T;ZLN<`ORWI
M\$$!\3@'#$:+:@5&#FN`(9/Z@_C#\\4#-KI:'+@8."KY5$3=PO%``@`A_?>B
M["!&__<I^CA&."(`(?WWFNP@1L3I'&C_]Q_ZXW@K<"!&8XAK<"-H&PJK<"-H
MZW#C>BMQ8XEK<:-H&PJK<:-HZW'C?"MR8XIK<B-I&PJK<B-IZW+C?BMS8XMK
M<Z-I&PJK<Z-IZW.4^",P*W1CC&MT(VH;"JMT(VKK=+WH\$']]X"\PO$X`@`A
M_?=>[,'G`DM[1!MH_?</O0"_0E4```A`+>D(@+WH`0`"`#X```!!````#```
M`$$````1````00```"<```!!````-@```$$````#````00````8```!!````
M%0```$$````/````00````X```!!````)@```$$````3````00```"D```!!
M`````@```$$````9````00````H```!!````"P```$$``````````````"5S
M+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`
M+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O
M````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"
M54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"
M04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'
M3$]"04Q?0TQ%04X`````,0```&QS965K(&9A:6QE9`````!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S````
M`'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@
M>6]U<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````<VAO
M<G0@<F5A9```)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ
M5D524TE/3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52
M`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE
M8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T
M(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM
M>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE
M7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&
M24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M
M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS
M=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?
M<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@[
M"FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ
M93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?
M<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR
M96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)
M0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X]
M(#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE
M.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U0
M3$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P
M+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M
M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D
M9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA
M;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*
M<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ
M<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I
M.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=
M*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-
M04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S
M("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N
M)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E
M("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*
M?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D
M;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R
M:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@
M34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M
M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U
M9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F
M)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@
M9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B
M)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S
M:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F
M9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L
M(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E
M<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68[
M"F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L
M(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@
M)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@
M)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M
M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T
M92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H
M)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M
M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M
M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO
M('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N
M86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68[
M"G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A
M<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P
M:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$
M5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q
M6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H
M*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD
M968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT
M('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN
M960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N
M*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]
M"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM
M>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN
M97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@
M(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@
M;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD
M9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E
M9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@
M(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A
M7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@
M>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE
M>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D
M8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV
M93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@
M)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G
M;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H
M<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N
M+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E
M>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6
M>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E
M('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P
M;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D
M;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#
M04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M
M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(
M12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C
M86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`]
M(")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D
M:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L*
M*&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@
M)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES
M>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID
M96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@
M0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]
M"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y]
M.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H
M*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN
M(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)
M3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W
M*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X
M<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I
M;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG
M="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@
M;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@
M)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`````0T%#2$4``#X```!!````#```
M`$$````1````00```"<```!!````-@```$$````#````00````8```!!````
M%0```$$````/````00````X```!!````)@```$$````3````00```"D```!!
M`````@```$$````9````00````H```!!````"P```$$``````````````,B:
M_W\!````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(T8``!-&````0```#8#```!````1@,```$```!0`P``
M#````,02```-````S#H``!D```"\C0``&P````0````:````P(T``!P````$
M````]?[_;Z`"```%````'`H```8```",`P``"@```,L$```+````$````!4`
M`````````P```,R.```"````X`$``!0````1````%P```.00```1````#!``
M`!(```#8````$P````@````>````"````/O__V\!```(_O__;[P/``#___]O
M`@```/#__V_H#@``^O__;PX`````````````````````````````````````
M````````````````````Q(T`````````````T!(``-`2``#0$@``T!(``-`2
M``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(`
M`-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``
MT!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0
M$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2
M``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``````
M````````````````````````````````````````````````````````````
M`````,D5````````!)````I005(N<&T*`````+`^``#$.P```````(0\``"(
M/```I#X``,P[``"L/@```````)`^``"8/@```````+@^``!'0T,Z("A58G5N
M='4@,30N,BXP+3=U8G5N='4Q*2`Q-"XR+C``03(```!A96%B:0`!*`````4W
M+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92YP86-K86=E`"YN;W1E
M+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A
M<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O
M;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````````
M````````````````````````"P````$````"````5`$``%0!```9````````
M```````!`````````!,````'`````@```'`!``!P`0``)```````````````
M!``````````F````!P````(```"4`0``E`$``.P```````````````0`````
M````-`````<````"````@`(``(`"```@```````````````$`````````$(`
M``#V__]O`@```*`"``"@`@``[`````8`````````!`````0```!,````"P``
M``(```",`P``C`,``)`&```'`````P````0````0````5`````,````"````
M'`H``!P*``#+!``````````````!`````````%P```#___]O`@```.@.``#H
M#@``T@````8``````````@````(```!I````_O__;P(```"\#P``O`\``%``
M```'`````@````0`````````>`````D````"````#!````P0``#8````!@``
M```````$````"````($````)````0@```.00``#D$```X`$```8````6````
M!`````@```"*`````0````8```#$$@``Q!(```P```````````````0`````
M````A0````$````&````T!(``-`2``#T`@`````````````$````!````)``
M```!````!@```,@5``#(%0``!"4`````````````"`````````"6`````0``
M``8```#,.@``S#H```@```````````````0`````````G`````$````"````
MU#H``-0Z``#X00`````````````$`````````*0````!``!P@@```,Q\``#,
M?```"`````X`````````!`````````"O`````0````(```#4?```U'P```0`
M``````````````0`````````N0````X````#````O(T``+Q]```$````````
M```````$````!````,4````/`````P```,"-``#`?0``!```````````````
M!`````0```#1````!@````,```#$C0``Q'T```@!```'``````````0````(
M````V@````$````#````S(X``,Q^```T`0`````````````$````!````-\`
M```!`````P````"0````@```2```````````````!`````````#E````"```
M``,```!(D```2(```!0```````````````0`````````Z@````$````P````
M`````$B````E```````````````!`````0```/,````#``!P``````````!M
M@```,P```````````````0`````````!`````P``````````````H(````,!
2``````````````$`````````
